Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1442)

Unified Diff: editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java

Issue 10034031: modified Run button to always run the last launched application (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java
===================================================================
--- editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java (revision 6439)
+++ editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java (working copy)
@@ -20,15 +20,15 @@
import org.eclipse.ui.PlatformUI;
/**
* A command handler to invoke the run action.
*/
-public class DartRunHandler extends AbstractHandler {
- private DartRunAction runAction;
+public class DartRunLastHandler extends AbstractHandler {
+ private DartRunLastAction runLastAction;
/**
* Create a new DartRunHandler.
*/
- public DartRunHandler() {
+ public DartRunLastHandler() {
}
@@ -39,12 +39,13 @@
return null;
}
- private DartRunAction getRunAction() {
- if (runAction == null) {
- runAction = new DartRunAction(PlatformUI.getWorkbench().getActiveWorkbenchWindow(), true);
+ private DartRunLastAction getRunAction() {
+ if (runLastAction == null) {
+ runLastAction = new DartRunLastAction(PlatformUI.getWorkbench().getActiveWorkbenchWindow(),
+ true);
}
- return runAction;
+ return runLastAction;
}
}
@@ -20,15 +20,15 @@
import org.eclipse.ui.PlatformUI;
/**
- * A command handler to invoke the run action.
+ * A command handler to invoke the run last action.
*/

Powered by Google App Engine
This is Rietveld 408576698